@@ -8,30 +8,43 @@ from psychopy.app.builder.experiment import Param
 
 thisFolder = path.abspath(path.dirname(__file__))#the absolute path to the folder containing this path
 iconFile = path.join(thisFolder,'mouse.png')
+tooltip = 'Mouse: query mouse position and buttons'
 
 class MouseComponent(BaseComponent):
     """An event class for checking the mouse location and buttons at given timepoints"""
-    def __init__(self, exp, parentName, name='mouse', startTime=0.0, duration='', save='final', 
-            forceEndTrialOnPress=True, timeRelativeTo='routine'):
+    def __init__(self, exp, parentName, name='mouse',
+                startType='time (s)', startVal=0.0,
+                stopType='duration (s)', stopVal=1.0,
+                startEstim='', durationEstim='',
+                save='final',forceEndRoutineOnPress=True, timeRelativeTo='routine'):
         self.type='Mouse'
         self.url="http://www.psychopy.org/builder/components/mouse.html"
         self.exp=exp#so we can access the experiment if necess
         self.exp.requirePsychopyLibs(['event'])
         #params
-        self.order = ['name', 'startTime','duration']#make sure that 'name' is at top of dlg
         self.params={}
+        self.order=[]
         self.params['name']=Param(name, valType='code', allowedTypes=[],
-            hint="Even mice have names!")
-        self.params['startTime']=Param(startTime, valType='code', allowedTypes=[],
+            hint="Even mice need names!")
+        self.params['startType']=Param(startType, valType='str',
+            allowedVals=['time (s)', 'frame N', 'condition'],
+            hint="How do you want to define your start point?")
+        self.params['stopType']=Param(stopType, valType='str',
+            allowedVals=['duration (s)', 'duration (frames)', 'time (s)', 'frame N', 'condition'],
+            hint="How do you want to define your end point?")
+        self.params['startVal']=Param(startVal, valType='code', allowedTypes=[],
+            hint="When does the mouse start being checked?")
+        self.params['stopVal']=Param(stopVal, valType='code', allowedTypes=[],
             updates='constant', allowedUpdates=[],
-            hint="The time that the mouse starts being checked")
-        self.params['duration']=Param(duration, valType='code', allowedTypes=[],
-            updates='constant', allowedUpdates=[],
-            hint="The duration during which the mouse is checked")
+            hint="When does the mouse stop being checked?")
+        self.params['startEstim']=Param(startEstim, valType='code', allowedTypes=[],
+            hint="(Optional) expected start (s), purely for representing in the timeline")
+        self.params['durationEstim']=Param(durationEstim, valType='code', allowedTypes=[],
+            hint="(Optional) expected duration (s), purely for representing in the timeline")
         self.params['saveMouseState']=Param(save, valType='str',
             allowedVals=['final','on click', 'every frame', 'never'],
             hint="How often should the mouse state (x,y,buttons) be stored? On every video frame, every click or just at the end of the Routine?")
-        self.params['forceEndTrialOnPress']=Param(forceEndTrialOnPress, valType='bool', allowedTypes=[],
+        self.params['forceEndRoutineOnPress']=Param(forceEndRoutineOnPress, valType='bool', allowedTypes=[],
             updates='constant', allowedUpdates=[],
             hint="Should a button press force the end of the routine (e.g end the trial)?")
         self.params['timeRelativeTo']=Param(timeRelativeTo, valType='str',
@@ -56,26 +69,39 @@ class MouseComponent(BaseComponent):
     def writeFrameCode(self,buff):
         """Write the code that will be called every frame
         """
-        forceEnd = self.params['forceEndTrialOnPress'].val
+        forceEnd = self.params['forceEndRoutineOnPress'].val
         routineClockName = self.exp.flow._currentRoutine._clockName
-        
+
         #only write code for cases where we are storing data as we go (each frame or each click)
         if self.params['saveMouseState'] not in ['every frame', 'on click'] and not forceEnd:
             return
-        
-        self.writeTimeTestCode(buff)#writes an if statement to determine whether to draw etc
-        buff.setIndentLevel(1, relative=True)#because of the 'if' statement of the time test
-        self.writeParamUpdates(buff, 'frame')
-        
+
+        buff.writeIndented("#*%s* updates\n" %(self.params['name']))
+        self.writeStartTestCode(buff)#writes an if statement to determine whether to draw etc
+        buff.writeIndented("%(name)s.status=STARTED\n" %(self.params))
+        buff.setIndentLevel(-1, relative=True)#to get out of the if statement
+        #test for stop (only if there was some setting for duration or stop)
+        if self.params['stopVal'].val not in ['', None, -1, 'None']:
+            self.writeStopTestCode(buff)#writes an if statement to determine whether to draw etc
+            buff.writeIndented("%(name)s.status=STOPPED\n" %(self.params))
+            buff.setIndentLevel(-1, relative=True)#to get out of the if statement
+
+        #if STARTED and not STOPPED!
+        buff.writeIndented("if %(name)s.status==STARTED:#only update if started and not stopped!\n" %(self.params))
+        buff.setIndentLevel(1, relative=True)#to get out of the if statement
+        dedentAtEnd=1#keep track of how far to dedent later
+
         #get a clock for timing
         if self.params['timeRelativeTo'].val=='experiment':clockStr = 'globalClock'
         elif self.params['timeRelativeTo'].val=='routine':clockStr = routineClockName
-        
+
         #write param checking code
         if self.params['saveMouseState'].val == 'on click' or forceEnd:
             buff.writeIndented("buttons = %(name)s.getPressed()\n" %(self.params))
             buff.writeIndented("if sum(buttons)>0:#ie if any button is pressed\n")
             buff.setIndentLevel(1, relative=True)
+            dedentAtEnd+=1
+        #only do this if buttons were pressed
         if self.params['saveMouseState'].val == 'on click':
             buff.writeIndented("x,y=%(name)s.getPos()\n" %(self.params))
             buff.writeIndented("%(name)s.x.append(x)\n" %(self.params))
@@ -84,16 +110,15 @@ class MouseComponent(BaseComponent):
             buff.writeIndented("%(name)s.midButton.append(buttons[1])\n" %(self.params))
             buff.writeIndented("%(name)s.rightButton.append(buttons[2])\n" %(self.params))
             buff.writeIndented("%s.time.append(%s.getTime())\n" %(self.params['name'], clockStr))
-            
+
         #does the response end the trial?
         if forceEnd==True:
             buff.writeIndented("#abort routine on response\n" %self.params)
             buff.writeIndented("continueRoutine=False\n")
-            
+
         #dedent
-        if self.params['saveMouseState'] == 'on click' or forceEnd:
-            buff.setIndentLevel(-2, relative=True)#'if' statement of the time test and button check
-        else: buff.setIndentLevel(-1, relative=True)#because of the 'if' statement of the time test
+        buff.setIndentLevel(-dedentAtEnd, relative=True)#'if' statement of the time test and button check
+
     def writeRoutineEndCode(self,buff):
         #some shortcuts
         name = self.params['name']
