@@ -5,13 +5,13 @@
 from _base import *
 from os import path
 from psychopy.app.builder.experiment import Param
-from psychopy.app.builder import inf # infinity
 import re
 
 __author__ = 'Jeremy Gray'
 
 thisFolder = path.abspath(path.dirname(__file__)) # the absolute path to the folder containing this path
 iconFile = path.join(thisFolder, 'ratingscale.png')
+tooltip = 'Rating scale: obtain numerical or categorical responses'
 
 class RatingScaleComponent(BaseComponent):
     """A class for presenting a rating scale as a builder component"""
@@ -24,8 +24,10 @@ class RatingScaleComponent(BaseComponent):
                  singleClick=False,
                  size=1.0,
                  pos='0, -0.4',
-                 startTime=0, duration='',
-                 forceEndTrial=True,
+                 startType='time (s)', startVal=0.0,
+                 stopType='condition', stopVal='',
+                 startEstim='', durationEstim='',
+                 forceEndRoutine=True,
                  storeRating=True, storeRatingTime=True,
                  lowAnchorText='', highAnchorText='',
                  customize_everything=''
@@ -34,16 +36,31 @@ class RatingScaleComponent(BaseComponent):
         self.url="http://www.psychopy.org/builder/components/ratingscale.html"
         self.exp=exp
         self.exp.requirePsychopyLibs(['visual', 'event'])
-        
+
         #params
         self.order = ['name', 'visualAnalogScale', 'categoryChoices', 'scaleDescription', 'low', 'high', 'size']
-        self.params = {} 
-        self.params['advancedParams'] = ['singleClick', 'startTime', 'forceEndTrial', 'size', 
-                        'pos', 'duration', 'storeRatingTime', 'storeRating', 'lowAnchorText', 'highAnchorText', 'customize_everything']
-        
+        self.params = {}
+        self.params['advancedParams'] = ['singleClick', 'forceEndRoutine', 'size',
+                        'pos', 'storeRatingTime', 'storeRating', 'lowAnchorText', 'highAnchorText', 'customize_everything']
+
         # normal params:
         self.params['name'] = Param(name, valType='code', allowedTypes=[],
             hint="A rating scale only collects the response; it does not display the stimulus to be rated.")
+        self.params['startType']=Param(startType, valType='str',
+            allowedVals=['time (s)', 'frame N', 'condition'],
+            hint="How do you want to define your start point?")
+        self.params['stopType']=Param(stopType, valType='str',
+            allowedVals=['duration (s)', 'duration (frames)', 'time (s)', 'frame N', 'condition'],
+            hint="How do you want to define your end point?")
+        self.params['startVal']=Param(startVal, valType='code', allowedTypes=[],
+            hint="When does the rating scale start being shown?")
+        self.params['stopVal']=Param(stopVal, valType='code', allowedTypes=[],
+            updates='constant', allowedUpdates=[],
+            hint="How long to wait for a response (blank is forever)")
+        self.params['startEstim']=Param(startEstim, valType='code', allowedTypes=[],
+            hint="(Optional) expected start (s) of stimulus, purely for representing in the timeline")
+        self.params['durationEstim']=Param(durationEstim, valType='code', allowedTypes=[],
+            hint="(Optional) expected duration (s) of stimulus, purely for representing in the timeline")
         self.params['visualAnalogScale'] = Param(visualAnalogScale, valType='bool', allowedTypes=[],
             updates='constant', allowedUpdates=[],
             hint="Show a continuous visual analog scale; returns 0.00 to 1.00; takes precedence over numeric scale or categorical choices")
@@ -57,7 +74,7 @@ class RatingScaleComponent(BaseComponent):
             updates='constant', allowedUpdates=[], hint="Lowest rating (low end of the scale); not used for categories.")
         self.params['high'] = Param(high, valType='code', allowedTypes=[],
             updates='constant', allowedUpdates=[], hint="Highest rating (top end of the scale); not used for categories.")
-        
+
         # advanced params:
         self.params['singleClick'] = Param(singleClick, valType='bool', allowedTypes=[],
             updates='constant', allowedUpdates=[],
@@ -73,10 +90,7 @@ class RatingScaleComponent(BaseComponent):
             hint="store the time taken to make the choice (in seconds)")
         self.params['pos'] = Param(pos, valType='str', allowedTypes=[],
             updates='constant', allowedUpdates=[], hint="x,y position on the screen")
-        self.params['duration'] = Param(duration, valType='code', allowedTypes=[],
-            updates='constant', allowedUpdates=[],
-            hint="How many seconds to wait for a response; leave blank for 'forever'")
-        self.params['forceEndTrial'] = Param(forceEndTrial, valType='bool', allowedTypes=[],
+        self.params['forceEndRoutine'] = Param(forceEndRoutine, valType='bool', allowedTypes=[],
             updates='constant', allowedUpdates=[],
             hint="Should accepting a rating cause the end of the routine (e.g. trial)?")
         self.params['lowAnchorText'] = Param(lowAnchorText, valType='str', allowedTypes=[],
@@ -88,15 +102,11 @@ class RatingScaleComponent(BaseComponent):
         self.params['customize_everything'] = Param(customize_everything, valType='str', allowedTypes=[],
             updates='constant', allowedUpdates=[],
             hint="Use this text to create the rating scale as you would in a code component; overrides all"+
-                " dialog settings except startTime, forceEndTrial, duration, storeRatingTime, storeRating")
-        
-        # required (?)
-        self.params['startTime'] = Param(0.0, valType='code', allowedTypes=[],
-            updates='constant', allowedUpdates=[], hint="")
-        
+                " dialog settings except time parameters, forceEndRoutine, storeRatingTime, storeRating")
+
     def writeInitCode(self, buff):
         # build up an initialization string for RatingScale():
-        init_str = "%(name)s=visual.RatingScale(win=win" % (self.params)
+        init_str = "%(name)s=visual.RatingScale(win=win, name='%(name)s'" % (self.params)
         if self.params['customize_everything'].val.strip() != '':
             # clean it up a little, remove win=*, leading / trailing typos
             self.params['customize_everything'].val = re.sub(r"[\\s,]*win=[^,]*,", '', self.params['customize_everything'].val)
@@ -104,10 +114,10 @@ class RatingScaleComponent(BaseComponent):
         else:
             init_str += ", escapeKeys=['escape']"
             # size:
-            try: s = float(self.params['size'].val) 
+            try: s = float(self.params['size'].val)
             except: s = 1.0
             init_str += ", displaySizeFactor=%.2f" % s
-            
+
             # position: x -> (x,x); x,y -> (x,y)
             try:
                 s = str(self.params['pos'].val)
@@ -116,7 +126,7 @@ class RatingScaleComponent(BaseComponent):
                 init_str += ",\n    pos=%s" % pos[0:2]
             except:
                 pass # pos = None
-                
+
             # type of scale:
             choices = str(self.params['categoryChoices'].val).strip().strip(',').lstrip().lstrip(',')
             scaleDescription = str(self.params['scaleDescription'].val)
@@ -154,7 +164,7 @@ class RatingScaleComponent(BaseComponent):
                     except ValueError:
                         if len(self.params['high'].val):
                             init_str += ", highAnchorText='"+self.params['high'].val+"'"
-                
+
             if not len(choices) and len(str(scaleDescription)):
                 init_str += ", scale='" + str(scaleDescription) +"'"
             if self.params['singleClick'].val:
@@ -162,37 +172,41 @@ class RatingScaleComponent(BaseComponent):
         # write the RatingScale() instantiation code:
         init_str += ")\n"
         buff.writeIndented(init_str)
-        
+
     def writeRoutineStartCode(self, buff):
-        buff.writeIndented("%(name)s.reset()\n" % (self.params)) 
-    
+        buff.writeIndented("%(name)s.reset()\n" % (self.params))
+        buff.writeIndented("%(name)s.status = NOT_STARTED\n" % (self.params))
+
     def writeFrameCode(self, buff):
         name = self.params['name']
+        buff.writeIndented("\n")
+        buff.writeIndented("#*%(name)s* updates\n" %(self.params))
         buff.writeIndented("%(name)s.draw()\n" % (self.params))
         # if requested, force end of trial when the subject 'accepts' the current rating:
-        if self.params['forceEndTrial']:
+        if self.params['forceEndRoutine'].val:
             buff.writeIndented("continueRoutine = %s.noResponse\n" % (name))
         # only need to do the following the first time it goes False, here gets set every frame:
         buff.writeIndented("if %s.noResponse == False:\n" % name)
         buff.setIndentLevel(1, relative=True)
+        buff.writeIndented("%(name)s.status = FINISHED\n" % (self.params))
         buff.writeIndented("%s.response = %s.getRating()\n" % (name, name));
         if self.params['storeRatingTime'].val:
-            buff.writeIndented("%s.rt = %s.getRT()\n" % (name, name)); 
+            buff.writeIndented("%s.rt = %s.getRT()\n" % (name, name));
         buff.setIndentLevel(-1, relative=True)
-    
+
     def writeRoutineEndCode(self, buff):
         name = self.params['name']
         if len(self.exp.flow._loopList):
             currLoop = self.exp.flow._loopList[-1] # last (outer-most) loop
         else:
             currLoop = None
-        
+
         #write the actual code
         if currLoop and (self.params['storeRating'].val or self.params['storeRatingTime'].val):
             if currLoop.type in ['StairHandler', 'QuestHandler']:
                 buff.writeIndented("#NB PsychoPy doesn't handle a 'correct answer' for ratingscale " +
                                "events so doesn't know what to tell a StairHandler (or QuestHandler)")
-            elif currLoop.type == 'TrialHandler': 
+            elif currLoop.type == 'TrialHandler':
                 if self.params['storeRating'].val == True:
                     buff.writeIndented("%s.addData('%s.response', %s.getRating())\n" \
                                        % (currLoop.params['name'], name, name))
@@ -201,4 +215,4 @@ class RatingScaleComponent(BaseComponent):
                                        % (currLoop.params['name'], name, name))
             else:
                 buff.writeIndented("#RatingScaleComponent: unknown loop type, not saving any data.")
-  
+
