@@ -91,7 +91,8 @@ class RunTimeInfo(dict):
         
         self['psychopyVersion'] = psychopyVersion
         self['psychopyHaveExtRush'] = rush(False) # NB: this looks weird, but avoids setting high-priority incidentally
-        githash = _getHashGitHead(dir=os.path.abspath(os.path.dirname(__file__)))
+        d = os.path.abspath(os.path.dirname(__file__))
+        githash = _getHashGitHead(dir=d) # should be .../psychopy/psychopy/
         if githash: 
             self['psychopyGitHead'] = githash
         
@@ -464,9 +465,23 @@ class RunTimeInfo(dict):
             print k,type(self[k]),self[k]
             
 def _getHashGitHead(dir=''):
-    git_hash = shellCall("cd " + dir + "; git rev-parse --verify HEAD", stderr=True)
-    git_branch = shellCall("cd " + dir + """; git branch | awk '$1=="*" {print $2}' """, stderr=True)
-    return git_branch[0].strip() + ' ' + git_hash[0].strip()
+    origDir = os.getcwd()
+    os.chdir(dir)
+    try:
+        git_hash = shellCall("git rev-parse --verify HEAD")
+    except OSError:
+        os.chdir(origDir)
+        return None
+    except WindowsError: # not defined on mac; OSError should catch lack of git
+        os.chdir(origDir)
+        return None
+    os.chdir(origDir)
+    git_branches = shellCall("git branch")
+    git_branch = [line.split()[1] for line in git_branches.splitlines() if line.startswith('*')]
+    if len(git_branch):
+        return git_branch[0] + ' ' + git_hash.strip()
+    else: # dir is not a git repo
+        return None
     
 def _getSvnVersion(file):
     """Tries to discover the svn version (revision #) for a file.
@@ -480,7 +495,10 @@ def _getSvnVersion(file):
         return None, None, None
     svnRev, svnLastChangedRev, svnUrl = None, None, None
     if sys.platform in ['darwin', 'linux2', 'freebsd']:
-        svninfo,stderr = shellCall('svn info "'+file+'"', stderr=True) # expects a filename, not dir
+        try:
+            svninfo,stderr = shellCall('svn info "'+file+'"', stderr=True) # expects a filename, not dir
+        except:
+            svninfo = ''
         for line in svninfo.splitlines():
             if line.find('URL:') == 0:
                 svnUrl = line.split()[1]
@@ -489,7 +507,10 @@ def _getSvnVersion(file):
             elif line.find('Last Changed Rev') == 0:
                 svnLastChangedRev = line.split()[3]
     else: # worked for me on Win XP sp2 with TortoiseSVN (SubWCRev.exe)
-        stdout,stderr = shellCall('subwcrev "'+file+'"', stderr=True)
+        try:
+            stdout,stderr = shellCall('subwcrev "'+file+'"', stderr=True)
+        except:
+            stdout = ''
         for line in stdout.splitlines():
             if line.find('Last committed at revision') == 0:
                 svnRev = line.split()[4]
@@ -512,7 +533,6 @@ def _getHgVersion(file):
         changeset = hgParentLines.splitlines()[0].split()[-1]
     except:
         changeset = ''
-    #else: changeset = hgParentLines.splitlines()[0].split()[-1]
     try:
         hgID,err = shellCall('hg id -nibt "'+os.path.dirname(file)+'"', stderr=True)
     except:
@@ -536,7 +556,7 @@ def _getUserNameUID():
     uid = '-1' 
     try:
         if sys.platform not in ['win32']:
-            uid = os.popen('id -u').read()
+            uid = core.shellCall('id -u')
         else:
             try:
                 uid = '1000'
