@@ -1,3 +1,5 @@
+#!/bin/sh
+
 echo DID YOU UPDATE THE CHANGELOG?
 sudo python setup.py sdist --format=zip
 sudo python setup.py egg_info
@@ -8,5 +10,8 @@ rm psychopy/prefSite.cfg
 
 sudo rm -r build
 sudo rm -r dist/PsychoPy2.app
+sudo rm -r ../dist/PsychoPy2.app
 python setupApp.py py2app #don't run this as sudo
 sudo chmod -R g+w dist/PsychoPy2.app
+
+mv dist/* ../dist/
\ No newline at end of file
